@@ -115,7 +115,7 @@ class ShipmentIn:
             move = cost['move']
             quantity = Decimal(str(move.quantity))
             if exp * quantity < difference:
-                cost['unit_shipment_cost'] = unit_shipment_cost + exp
+                cost['unit_shipment_cost'] += exp
                 difference -= exp * quantity
             if difference < exp:
                 break
@@ -128,8 +128,8 @@ class ShipmentIn:
             unit_shipment_cost = unit_shipment_cost.quantize(
                 exp, rounding=ROUND_HALF_EVEN)
             Move.write([move], {
-                    'unit_price': move.unit_price + cost['unit_shipment_cost'],
-                    'unit_shipment_cost': cost['unit_shipment_cost'],
+                    'unit_price': move.unit_price + unit_shipment_cost,
+                    'unit_shipment_cost': unit_shipment_cost,
                     })
 
     @classmethod
@@ -157,15 +157,17 @@ class Move:
     def _get_account_stock_move_lines(self, type_):
         pool = Pool()
         AccountMoveLine = pool.get('account.move.line')
+        Currency = pool.get('currency.currency')
         move_lines = super(Move, self)._get_account_stock_move_lines(type_)
         if (type_.startswith('in_')
                 and self.unit_shipment_cost
-                and self.shipment_in
-                and self.shipment_in.carrier):
-            shipment_cost = self.company.currency.round(
-                Decimal(str(self.quantity)) * self.unit_shipment_cost)
+                and self.shipment
+                and self.shipment.carrier):
+            shipment_cost = Currency.compute(self.currency,
+                Decimal(str(self.quantity)) * self.unit_shipment_cost,
+                self.company.currency)
             shipment_cost_account = \
-                self.shipment_in.carrier.carrier_product.account_expense_used
+                self.shipment.carrier.carrier_product.account_expense_used
             account = self.product.account_stock_supplier_used
             for move_line in move_lines:
                 if move_line.account == account:
@@ -180,3 +182,17 @@ class Move:
             else:
                 raise AssertionError('missing account_stock_supplier')
         return move_lines
+
+    # Remove shipment cost if account_stock_anglo_saxon is installed
+    @classmethod
+    def _get_anglo_saxon_move(cls, moves, quantity, type_):
+        pool = Pool()
+        Currency = pool.get('currency.currency')
+        for move, qty, cost_price in super(Move, cls)._get_anglo_saxon_move(
+                moves, quantity, type_):
+            if (type_.startswith('in_')
+                    and move.unit_shipment_cost):
+                shipment_cost = Currency.compute(move.currency,
+                    move.unit_shipment_cost, move.company.currency)
+                cost_price -= shipment_cost
+            yield move, qty, cost_price
